regionReport-deprecated: Deprecated functions in package regionReport
Description
These functions are provided for compatibility with older versions
of regionReport only, and will be defunct at the next release.
Usage
derfinder_report()
render_report()
Details
The following functions are deprecated and will be made defunct; use
the replacement indicated below: